Index: netutils.c
===================================================================
--- netutils.c	(revision 1761)
+++ netutils.c	(working copy)
@@ -53,7 +53,17 @@
 	exit (STATE_CRITICAL);
 }
 
+void
+socket_timeout_alarm_ok_handler (int sig)
+{
+	if (sig == SIGALRM)
+		printf (_("OK - Socket timeout after %d seconds\n"), socket_timeout);
+	else
+		printf (_("OK - Abnormal timeout after %d seconds\n"), socket_timeout);
 
+	exit (STATE_OK);
+}
+
 /* connects to a host on a specified tcp port, sends a string, and gets a 
 	 response. loops on select-recv until timeout or eof to get all of a 
 	 multi-packet answer */
Index: netutils.h
===================================================================
--- netutils.h	(revision 1761)
+++ netutils.h	(working copy)
@@ -50,6 +50,7 @@
 #endif /* HAVE_SYS_UN_H */
 
 RETSIGTYPE socket_timeout_alarm_handler (int) __attribute__((noreturn));
+RETSIGTYPE socket_timeout_alarm_ok_handler (int) __attribute__((noreturn));
 
 /* process_request and wrapper macros */
 #define process_tcp_request(addr, port, sbuf, rbuf, rsize) \
Index: check_http.c
===================================================================
--- check_http.c	(revision 1761)
+++ check_http.c	(working copy)
@@ -123,6 +123,8 @@
 char *http_post_data;
 char *http_content_type;
 char buffer[MAX_INPUT_BUFFER];
+int  refuse_ok = FALSE;
+int  timeout_ok = FALSE;
 
 int process_arguments (int, char **);
 static char *base64 (const char *bin, size_t len);
@@ -155,7 +157,7 @@
       server_port, server_url);
 
   /* initialize alarm signal handling, set socket timeout, start timer */
-  (void) signal (SIGALRM, socket_timeout_alarm_handler);
+  (void) signal (SIGALRM, socket_timeout_alarm_ok_handler);
   (void) alarm (socket_timeout);
   gettimeofday (&tv, NULL);
 
@@ -203,6 +205,8 @@
     {"invert-regex", no_argument, NULL, INVERT_REGEX},
     {"use-ipv4", no_argument, 0, '4'},
     {"use-ipv6", no_argument, 0, '6'},
+    {"refuse-ok", no_argument, 0, 'o'},
+    {"timeout-ok", no_argument, 0, 'O'},
     {0, 0, 0, 0}
   };
 
@@ -223,7 +227,7 @@
   }
 
   while (1) {
-    c = getopt_long (argc, argv, "Vvh46t:c:w:A:k:H:P:T:I:a:e:p:s:R:r:u:f:C:nlLSm:M:N", longopts, &option);
+    c = getopt_long (argc, argv, "Vvh46t:c:w:A:k:H:P:T:I:a:e:p:s:R:r:u:f:C:nlLSm:M:NoO", longopts, &option);
     if (c == -1 || c == EOF)
       break;
 
@@ -408,6 +412,12 @@
     case 'N': /* no-body */
       no_body = TRUE;
       break;
+    case 'o': /* refuse-ok */
+      refuse_ok = TRUE;
+      break;
+    case 'O': /* timeout-ok */
+      timeout_ok = TRUE;
+      break;  
     case 'M': /* max-age */
                   {
                     int L = strlen(optarg);
@@ -766,8 +776,12 @@
   int result = STATE_UNKNOWN;
 
   /* try to connect to the host at the given port number */
-  if (my_tcp_connect (server_address, server_port, &sd) != STATE_OK)
-    die (STATE_CRITICAL, _("HTTP CRITICAL - Unable to open TCP socket\n"));
+  if (my_tcp_connect (server_address, server_port, &sd) != STATE_OK) {
+    if (refuse_ok) 
+      die (STATE_OK, _("HTTP OK - Unable to open TCP socket\n"));
+    else
+      die (STATE_CRITICAL, _("HTTP CRITICAL - Unable to open TCP socket\n"));
+  }
 #ifdef HAVE_SSL
   if (use_ssl == TRUE) {
     np_net_ssl_init(sd);
@@ -1330,6 +1344,10 @@
   printf ("    %s\n", _("How to handle redirected pages"));
   printf (" %s\n", "-m, --pagesize=INTEGER<:INTEGER>");
   printf ("    %s\n", _("Minimum page size required (bytes) : Maximum page size required (bytes)"));
+  printf (" %s\n", "-o, --refuse-ok");
+  printf ("    %s\n", _("status as OK if tcp connection can't establish"));
+  printf (" %s\n", "-O, --timeout-ok");
+  printf ("    %s\n", _("status as OK if socket timeout happens"));
 
   printf (_(UT_WARN_CRIT));
 
